"""Type stub for wishful.static namespace.

This stub helps IDEs and type checkers understand that wishful.static.*
is a valid namespace for dynamically generated modules.
"""

def __getattr__(name: str) -> object: ...
